.. _unittests-label:

Unit tests
====================

Check the `test coverage <../htmlcoverage/index.html>`_.

.. automodule::  tests.common_tests
    :members:
    :undoc-members:

.. automodule::  tests.test_pydblite
    :members:
    :undoc-members:

.. automodule::  tests.test_pydblite_sqlite
    :members:
    :undoc-members:
